==> scummvm_0.11.99-2.tar.gz: scummvm-0.11.99/backends/plugins/dc/dc-provider.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-12-0/backends/plugins/dc/dc-provider.h $
 * $Id: dc-provider.h 32085 2008-05-13 13:24:49Z jvprat $
 *
 */

#ifndef BACKENDS_PLUGINS_DC_H
#define BACKENDS_PLUGINS_DC_H

#include "base/plugins.h"

#if defined(DYNAMIC_MODULES) && defined(__DC__)

class DCPluginProvider : public FilePluginProvider {
protected:
	Plugin* createPlugin(const Common::String &filename) const;

	bool isPluginFilename(const Common::String &filename) const;

	virtual void addCustomDirectories(Common::StringList &dirs) const {
		dirs.push_back("/");
	}
};

#endif // defined(DYNAMIC_MODULES) && defined(__DC__)

#endif

==> scummvm_0.13.0-2.tar.gz: scummvm-0.13.0/backends/plugins/dc/dc-provider.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-13-0/backends/plugins/dc/dc-provider.h $
 * $Id: dc-provider.h 34716 2008-10-02 16:58:59Z fingolfin $
 *
 */

#ifndef BACKENDS_PLUGINS_DC_H
#define BACKENDS_PLUGINS_DC_H

#include "base/plugins.h"

#if defined(DYNAMIC_MODULES) && defined(__DC__)

class DCPluginProvider : public FilePluginProvider {
protected:
	Plugin* createPlugin(const Common::FSNode &node) const;

	bool isPluginFilename(const Common::FSNode &node) const;

	virtual void addCustomDirectories(Common::StringList &dirs) const {
		dirs.push_back("/");
	}
};

#endif // defined(DYNAMIC_MODULES) && defined(__DC__)

#endif
